/// <reference types="node" />
import { InflectionBase, FieldWithHooksFunction, InputFieldWithHooksFunction, GetDataFromParsedResolveInfoFragmentFunction } from "./makeNewBuild";
import { GraphQLType, GraphQLNamedType, GraphQLInterfaceType, GraphQLObjectTypeConfig, GraphQLSchema, GraphQLResolveInfo, GraphQLSchemaConfig, GraphQLObjectType, GraphQLInputObjectType, GraphQLInputObjectTypeConfig, GraphQLScalarType, GraphQLScalarTypeConfig, GraphQLInterfaceTypeConfig, GraphQLUnionType, GraphQLUnionTypeConfig, GraphQLEnumType, GraphQLEnumTypeConfig, GraphQLFieldConfigMap, GraphQLFieldConfig, GraphQLFieldConfigArgumentMap, GraphQLInputFieldConfigMap, GraphQLInputFieldConfig, GraphQLEnumValueConfigMap, GraphQLEnumValueConfig, GraphQLOutputType } from "graphql";
import EventEmitter = require("events");
import { LiveCoordinator } from "./Live";
import { ResolveTree } from "graphql-parse-resolve-info";
import { NodeFetcher } from "./plugins/NodePlugin";
export { FieldWithHooksFunction, InputFieldWithHooksFunction };
export interface GraphileResolverContext {
}
export interface DirectiveMap {
    [directiveName: string]: {
        [directiveArgument: string]: any;
    };
}
export interface GraphileBuildOptions {
    subscriptions?: boolean;
    live?: boolean;
    nodeIdFieldName?: string;
    dontSwallowErrors?: boolean;
}
export declare type Options = GraphileBuildOptions;
export interface Plugin {
    (builder: SchemaBuilder, options: GraphileBuildOptions): Promise<void> | void;
    displayName?: string;
}
export declare type InitObject = never;
declare type TriggerChangeType = () => void;
/**
 * This contains all the possibilities for lookahead data when raw (submitted
 * directly from `addDataGenerator` functions, etc). It's up to the plugins
 * that define these entries to declare them using declaration merging.
 *
 * NOTE: the types of these entries are concrete (e.g. `usesCursor: boolean`)
 * because we need the concrete types to build ResolvedLookAhead. We then use
 * `Partial<LookAheadData>` in the relevant places if we need fields to be
 * optional.
 */
export interface LookAheadData {
}
/**
 * This contains all the possibilities for lookahead data, once "baked". It's
 * an object that maps from key (string) to an array of entries for that type.
 *
 * We made this generic so that TypeScript has to look it up _after_ the
 * declaration merging has taken place, rather than computing it as an empty
 * object ahead of time.
 */
export declare type ResolvedLookAhead<T extends LookAheadData = LookAheadData> = {
    [P in keyof T]?: Array<T[P]>;
};
export interface Inflection extends InflectionBase {
}
export interface GraphileObjectTypeConfig<TSource, TContext, TArgs = {
    [key: string]: any;
}> extends Omit<GraphQLObjectTypeConfig<TSource, TContext, TArgs>, "fields"> {
    fields?: GraphQLFieldConfigMap<TSource, TContext, TArgs> | ((context: ContextGraphQLObjectTypeFields) => GraphQLFieldConfigMap<TSource, TContext, TArgs>);
}
export interface GraphileInputObjectTypeConfig extends Omit<GraphQLInputObjectTypeConfig, "fields"> {
    fields?: GraphQLInputFieldConfigMap | ((context: ContextGraphQLInputObjectTypeFields) => GraphQLInputFieldConfigMap);
}
export interface GraphileUnionTypeConfig<TSource, TContext> extends Omit<GraphQLUnionTypeConfig<TSource, TContext>, "types"> {
    types?: GraphQLObjectType[] | ((context: ContextGraphQLUnionTypeTypes) => GraphQLObjectType[]);
}
export interface BuildBase {
    options: GraphileBuildOptions;
    graphileBuildVersion: string;
    versions: {
        [packageName: string]: string;
    };
    hasVersion(packageName: string, range: string, options?: {
        includePrerelease?: boolean;
    }): boolean;
    _pluginMeta: any;
    graphql: typeof import("graphql");
    parseResolveInfo: typeof import("graphql-parse-resolve-info").parseResolveInfo;
    simplifyParsedResolveInfoFragmentWithType: typeof import("graphql-parse-resolve-info").simplifyParsedResolveInfoFragmentWithType;
    getSafeAliasFromResolveInfo: (resolveInfo: GraphQLResolveInfo) => string;
    getSafeAliasFromAlias: (alias: string) => string;
    resolveAlias: (data: {}, _args: unknown, _context: unknown, resolveInfo: GraphQLResolveInfo) => string;
    addType: (type: GraphQLNamedType, origin: string | null | undefined) => void;
    getTypeByName: (typeName: string) => GraphQLType | null | undefined;
    extend: <Obj1 extends object, Obj2 extends object>(base: Obj1, extra: Obj2, hint: string) => Obj1 & Obj2;
    newWithHooks(constructor: typeof GraphQLSchema, spec: Partial<GraphQLSchemaConfig>, scope: ScopeGraphQLSchema): GraphQLSchema;
    newWithHooks(constructor: typeof GraphQLSchema, spec: Partial<GraphQLSchemaConfig>, scope: ScopeGraphQLSchema, performNonEmptyFieldsCheck?: boolean): GraphQLSchema | null;
    newWithHooks(constructor: typeof GraphQLScalarType, spec: GraphQLScalarTypeConfig<any, any>, scope: ScopeGraphQLScalarType): GraphQLScalarType;
    newWithHooks(constructor: typeof GraphQLScalarType, spec: GraphQLScalarTypeConfig<any, any>, scope: ScopeGraphQLScalarType, performNonEmptyFieldsCheck?: boolean): GraphQLScalarType | null;
    newWithHooks(constructor: typeof GraphQLObjectType, spec: GraphileObjectTypeConfig<any, any>, scope: ScopeGraphQLObjectType): GraphQLObjectType;
    newWithHooks(constructor: typeof GraphQLObjectType, spec: GraphileObjectTypeConfig<any, any>, scope: ScopeGraphQLObjectType, performNonEmptyFieldsCheck?: boolean): GraphQLObjectType | null;
    newWithHooks(constructor: typeof GraphQLInterfaceType, spec: GraphQLInterfaceTypeConfig<any, any, any>, scope: ScopeGraphQLInterfaceType): GraphQLInterfaceType;
    newWithHooks(constructor: typeof GraphQLInterfaceType, spec: GraphQLInterfaceTypeConfig<any, any, any>, scope: ScopeGraphQLInterfaceType, performNonEmptyFieldsCheck?: boolean): GraphQLInterfaceType | null;
    newWithHooks(constructor: typeof GraphQLUnionType, spec: GraphileUnionTypeConfig<any, any>, scope: ScopeGraphQLUnionType): GraphQLUnionType;
    newWithHooks(constructor: typeof GraphQLUnionType, spec: GraphileUnionTypeConfig<any, any>, scope: ScopeGraphQLUnionType, performNonEmptyFieldsCheck?: boolean): GraphQLUnionType | null;
    newWithHooks(constructor: typeof GraphQLEnumType, spec: GraphQLEnumTypeConfig, scope: ScopeGraphQLEnumType): GraphQLEnumType;
    newWithHooks(constructor: typeof GraphQLEnumType, spec: GraphQLEnumTypeConfig, scope: ScopeGraphQLEnumType, performNonEmptyFieldsCheck?: boolean): GraphQLEnumType | null;
    newWithHooks(constructor: typeof GraphQLInputObjectType, spec: GraphileInputObjectTypeConfig, scope: ScopeGraphQLInputObjectType): GraphQLInputObjectType;
    newWithHooks(constructor: typeof GraphQLInputObjectType, spec: GraphileInputObjectTypeConfig, scope: ScopeGraphQLInputObjectType, performNonEmptyFieldsCheck?: boolean): GraphQLInputObjectType | null;
    /**
     * @deprecated use fieldDataGeneratorsByFieldNameByType instead (they're the same, but that one is named better)
     */
    fieldDataGeneratorsByType: Map<GraphQLNamedType, {
        [fieldName: string]: DataGeneratorFunction[];
    }>;
    fieldDataGeneratorsByFieldNameByType: Map<GraphQLNamedType, {
        [fieldName: string]: DataGeneratorFunction[];
    }>;
    fieldArgDataGeneratorsByFieldNameByType: Map<GraphQLNamedType, {
        [fieldName: string]: ArgDataGeneratorFunction[];
    }>;
    scopeByType: Map<GraphQLType, SomeScope>;
    inflection: Inflection;
    swallowError: (e: Error) => void;
    resolveNode: typeof import("./resolveNode").default;
    status: {
        currentHookName: string | null | undefined;
        currentHookEvent: string | null | undefined;
    };
    liveCoordinator: LiveCoordinator;
}
export interface Build extends BuildBase {
    $$isQuery: symbol;
    nodeIdFieldName: string;
    $$nodeType: symbol;
    nodeFetcherByTypeName: {
        [typeName: string]: NodeFetcher;
    };
    getNodeIdForTypeAndIdentifiers: (Type: import("graphql").GraphQLType, ...identifiers: Array<unknown>) => string;
    getTypeAndIdentifiersFromNodeId: (nodeId: string) => {
        Type: import("graphql").GraphQLType;
        identifiers: Array<unknown>;
    };
    addNodeFetcherForTypeName: (typeName: string, fetcher: NodeFetcher) => void;
    getNodeAlias: (typeName: string) => string;
    getNodeType: (alias: string) => import("graphql").GraphQLType;
    setNodeAlias: (typeName: string, alias: string) => void;
}
export interface Scope {
    __origin?: string | null | undefined;
    directives?: DirectiveMap;
}
export declare type DataGeneratorFunction = {
    (parsedResolveInfoFragment: ResolveTree, ReturnType: GraphQLOutputType, data: ResolvedLookAhead): Partial<LookAheadData>;
    displayName?: string;
};
export declare type ArgDataGeneratorFunction = {
    (args: {
        [key: string]: unknown;
    }, ReturnType: GraphQLOutputType, data: ResolvedLookAhead): Partial<LookAheadData>;
    displayName?: string;
};
export interface Context {
    scope: Scope;
    type: "Build" | "Inflection" | "Init" | "GraphQLSchema" | "GraphQLScalarType" | "GraphQLObjectType" | "GraphQLInterfaceType" | "GraphQLUnionType" | "GraphQLEnumType" | "GraphQLInputObjectType" | "Finalize";
}
export interface ScopeBuild extends Scope {
}
export interface ContextBuild extends Context {
    scope: ScopeBuild;
    type: "Build";
}
export interface ScopeInflection extends Scope {
}
export interface ContextInflection extends Context {
    scope: ScopeInflection;
    type: "Inflection";
}
export interface ScopeInit extends Scope {
}
export interface ContextInit extends Context {
    scope: ScopeInit;
    type: "Init";
}
export interface ScopeGraphQLSchema extends Scope {
    isSchema: true;
}
export interface ContextGraphQLSchema extends Context {
    scope: ScopeGraphQLSchema;
    type: "GraphQLSchema";
}
export interface ScopeGraphQLScalarType extends Scope {
}
export interface ContextGraphQLScalarType extends Context {
    scope: ScopeGraphQLScalarType;
    type: "GraphQLScalarType";
}
export interface ScopeGraphQLObjectType extends Scope {
    isRootQuery?: boolean;
    isRootMutation?: boolean;
    isRootSubscription?: boolean;
    isMutationPayload?: boolean;
    isPageInfo?: boolean;
}
export interface ContextGraphQLObjectTypeBase extends Context {
    scope: ScopeGraphQLObjectType;
    type: "GraphQLObjectType";
}
export interface ContextGraphQLObjectType extends ContextGraphQLObjectTypeBase {
    addDataGeneratorForField: (fieldName: string, fn: DataGeneratorFunction) => void;
    /** YOU PROBABLY DON'T WANT THIS! */
    recurseDataGeneratorsForField(fieldName: string, iKnowWhatIAmDoing?: boolean): void;
}
export interface ScopeGraphQLObjectTypeInterfaces extends ScopeGraphQLObjectType {
}
export interface ContextGraphQLObjectTypeInterfaces extends ContextGraphQLObjectTypeBase {
    scope: ScopeGraphQLObjectTypeInterfaces;
    Self: GraphQLObjectType;
    GraphQLObjectType: GraphileObjectTypeConfig<any, any>;
}
export interface ScopeGraphQLObjectTypeFields extends ScopeGraphQLObjectType {
}
export interface ContextGraphQLObjectTypeFields extends ContextGraphQLObjectType {
    scope: ScopeGraphQLObjectTypeFields;
    addDataGeneratorForField: (fieldName: string, fn: DataGeneratorFunction) => void;
    recurseDataGeneratorsForField: (fieldName: string, iKnowWhatIAmDoing: boolean) => void;
    Self: GraphQLObjectType;
    GraphQLObjectType: GraphQLObjectTypeConfig<any, any>;
    fieldWithHooks: FieldWithHooksFunction;
}
export interface ScopeGraphQLObjectTypeFieldsField extends ScopeGraphQLObjectType {
    fieldName?: string;
    autoField?: boolean;
    fieldDirectives?: DirectiveMap;
    isLiveField?: boolean;
    originalField?: import("graphql").GraphQLField<any, any>;
    isRootNodeField?: boolean;
    isPageInfoHasNextPageField?: boolean;
    isPageInfoHasPreviousPageField?: boolean;
}
export interface ScopeGraphQLObjectTypeFieldsFieldWithFieldName extends ScopeGraphQLObjectTypeFieldsField {
    fieldName: string;
}
export interface ContextGraphQLObjectTypeFieldsField extends ContextGraphQLObjectTypeBase {
    scope: ScopeGraphQLObjectTypeFieldsFieldWithFieldName;
    Self: GraphQLObjectType;
    addDataGenerator: (fn: DataGeneratorFunction) => void;
    addArgDataGenerator: (fn: ArgDataGeneratorFunction) => void;
    getDataFromParsedResolveInfoFragment: GetDataFromParsedResolveInfoFragmentFunction;
}
export interface ScopeGraphQLObjectTypeFieldsFieldArgs extends ScopeGraphQLObjectTypeFieldsField {
    fieldName: string;
}
export interface ContextGraphQLObjectTypeFieldsFieldArgs extends ContextGraphQLObjectTypeFieldsField {
    scope: ScopeGraphQLObjectTypeFieldsFieldArgs;
    Self: GraphQLObjectType;
    field: GraphQLFieldConfig<any, any>;
    returnType: GraphQLOutputType;
}
export interface ScopeGraphQLInterfaceType extends Scope {
}
export interface ContextGraphQLInterfaceType extends Context {
    scope: ScopeGraphQLInterfaceType;
    type: "GraphQLInterfaceType";
}
export interface ScopeGraphQLUnionType extends Scope {
}
export interface ContextGraphQLUnionType extends Context {
    scope: ScopeGraphQLUnionType;
    type: "GraphQLUnionType";
}
export interface ScopeGraphQLUnionTypeTypes extends ScopeGraphQLUnionType {
}
export interface ContextGraphQLUnionTypeTypes extends ContextGraphQLUnionType {
    scope: ScopeGraphQLUnionTypeTypes;
    Self: GraphQLUnionType;
    GraphQLUnionType: GraphileUnionTypeConfig<any, any>;
}
export interface ScopeGraphQLInputObjectType extends Scope {
    isMutationInput?: boolean;
}
export interface ContextGraphQLInputObjectType extends Context {
    scope: ScopeGraphQLInputObjectType;
    type: "GraphQLInputObjectType";
}
export interface ScopeGraphQLInputObjectTypeFields extends ScopeGraphQLInputObjectType {
}
export interface ContextGraphQLInputObjectTypeFields extends ContextGraphQLInputObjectType {
    scope: ScopeGraphQLInputObjectTypeFields;
    Self: GraphQLInputObjectType;
    GraphQLInputObjectType: GraphileInputObjectTypeConfig;
    fieldWithHooks: InputFieldWithHooksFunction;
}
export interface ScopeGraphQLInputObjectTypeFieldsField extends ScopeGraphQLInputObjectType {
    fieldName?: string;
    autoField?: boolean;
}
export interface ScopeGraphQLInputObjectTypeFieldsFieldWithFieldName extends ScopeGraphQLInputObjectTypeFieldsField {
    fieldName: string;
}
export interface ContextGraphQLInputObjectTypeFieldsField extends ContextGraphQLInputObjectType {
    scope: ScopeGraphQLInputObjectTypeFieldsFieldWithFieldName;
    Self: GraphQLInputObjectType;
}
export interface ScopeGraphQLEnumType extends Scope {
}
export interface ContextGraphQLEnumType extends Context {
    scope: ScopeGraphQLEnumType;
    type: "GraphQLEnumType";
}
export interface ScopeGraphQLEnumTypeValues extends ScopeGraphQLEnumType {
}
export interface ContextGraphQLEnumTypeValues extends ContextGraphQLEnumType {
    scope: ScopeGraphQLEnumTypeValues;
}
export interface ScopeGraphQLEnumTypeValuesValue extends ScopeGraphQLEnumType {
}
export interface ContextGraphQLEnumTypeValuesValue extends ContextGraphQLEnumType {
    scope: ScopeGraphQLEnumTypeValuesValue;
}
export interface ScopeFinalize extends Scope {
}
export interface ContextFinalize extends Context {
    scope: ScopeFinalize;
    type: "Finalize";
}
export declare type SomeScope = Scope | ScopeBuild | ScopeInflection | ScopeInit | ScopeGraphQLSchema | ScopeGraphQLScalarType | ScopeGraphQLObjectType | ScopeGraphQLObjectTypeInterfaces | ScopeGraphQLObjectTypeFields | ScopeGraphQLObjectTypeFieldsField | ScopeGraphQLObjectTypeFieldsFieldWithFieldName | ScopeGraphQLObjectTypeFieldsFieldArgs | ScopeGraphQLInterfaceType | ScopeGraphQLUnionType | ScopeGraphQLUnionTypeTypes | ScopeGraphQLInputObjectType | ScopeGraphQLInputObjectTypeFields | ScopeGraphQLInputObjectTypeFieldsField | ScopeGraphQLInputObjectTypeFieldsFieldWithFieldName | ScopeGraphQLEnumType | ScopeGraphQLEnumTypeValues | ScopeGraphQLEnumTypeValuesValue | ScopeFinalize;
export interface Hook<Type, TContext extends Context, TBuild = Build> {
    (input: Type, build: TBuild, context: TContext): Type;
    displayName?: string;
    provides?: Array<string>;
    before?: Array<string>;
    after?: Array<string>;
}
export declare type WatchUnwatch = (triggerChange: TriggerChangeType) => void;
export declare type SchemaListener = (newSchema: GraphQLSchema) => void;
declare class SchemaBuilder extends EventEmitter {
    options: GraphileBuildOptions;
    watchers: Array<WatchUnwatch>;
    unwatchers: Array<WatchUnwatch>;
    triggerChange: TriggerChangeType | null | undefined;
    depth: number;
    hooks: {
        [a: string]: Array<Hook<any, any>>;
    };
    _currentPluginName: string | null | undefined;
    _generatedSchema: GraphQLSchema | null | undefined;
    _explicitSchemaListener: SchemaListener | null | undefined;
    _busy: boolean;
    _watching: boolean;
    constructor(options: GraphileBuildOptions);
    _setPluginName(name: string | null | undefined): void;
    hook(hookName: "build", fn: Hook<Partial<Build> & BuildBase, ContextBuild, BuildBase>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "inflection", fn: Hook<Partial<Inflection> & InflectionBase, ContextInflection, BuildBase>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "init", fn: Hook<InitObject, ContextInit>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "GraphQLSchema", fn: Hook<GraphQLSchemaConfig, ContextGraphQLSchema>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook<TSource, TContext>(hookName: "GraphQLObjectType", fn: Hook<GraphQLObjectTypeConfig<TSource, TContext>, ContextGraphQLObjectType>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "GraphQLObjectType:interfaces", fn: Hook<Array<GraphQLInterfaceTypeConfig<any, any>>, ContextGraphQLObjectTypeInterfaces>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook<TSource, TContext>(hookName: "GraphQLObjectType:fields", fn: Hook<GraphQLFieldConfigMap<TSource, TContext>, ContextGraphQLObjectTypeFields>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook<TSource, TContext>(hookName: "GraphQLObjectType:fields:field", fn: Hook<GraphQLFieldConfig<TSource, TContext>, ContextGraphQLObjectTypeFieldsField>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "GraphQLObjectType:fields:field:args", fn: Hook<GraphQLFieldConfigArgumentMap, ContextGraphQLObjectTypeFieldsFieldArgs>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "GraphQLInputObjectType", fn: Hook<GraphileInputObjectTypeConfig, ContextGraphQLInputObjectType>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "GraphQLInputObjectType:fields", fn: Hook<GraphQLInputFieldConfigMap, ContextGraphQLInputObjectTypeFields>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "GraphQLInputObjectType:fields:field", fn: Hook<GraphQLInputFieldConfig, ContextGraphQLInputObjectTypeFieldsField>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "GraphQLEnumType", fn: Hook<GraphQLEnumTypeConfig, ContextGraphQLEnumType>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "GraphQLEnumType:values", fn: Hook<GraphQLEnumValueConfigMap, ContextGraphQLEnumTypeValues>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "GraphQLEnumType:values:value", fn: Hook<GraphQLEnumValueConfig, ContextGraphQLEnumTypeValuesValue>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook<TSource, TContext>(hookName: "GraphQLUnionType", fn: Hook<GraphQLUnionTypeConfig<TSource, TContext>, ContextGraphQLUnionType>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "GraphQLUnionType:types", fn: Hook<Array<GraphileObjectTypeConfig<any, any>>, ContextGraphQLUnionTypeTypes>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    hook(hookName: "finalize", fn: Hook<GraphQLSchema, ContextFinalize>, provides?: Array<string>, before?: Array<string>, after?: Array<string>): void;
    applyHooks(build: BuildBase, hookName: "build", input: Partial<Build> & BuildBase, context: ContextBuild, debugStr?: string): Build;
    applyHooks(build: BuildBase, hookName: "inflection", input: Partial<Inflection> & InflectionBase, context: ContextInflection, debugStr?: string): Inflection;
    applyHooks(build: Build, hookName: "init", input: InitObject, context: ContextInit, debugStr?: string): InitObject;
    applyHooks(build: Build, hookName: "GraphQLSchema", input: GraphQLSchemaConfig, context: ContextGraphQLSchema, debugStr?: string): GraphQLSchemaConfig;
    applyHooks(build: Build, hookName: "GraphQLScalarType", input: GraphQLScalarTypeConfig<any, any>, context: ContextGraphQLScalarType, debugStr?: string): GraphQLScalarTypeConfig<any, any>;
    applyHooks(build: Build, hookName: "GraphQLObjectType", input: GraphileObjectTypeConfig<any, any>, context: ContextGraphQLObjectType, debugStr?: string): GraphQLObjectTypeConfig<any, any>;
    applyHooks(build: Build, hookName: "GraphQLObjectType:interfaces", input: Array<GraphQLInterfaceTypeConfig<any, any, any>>, context: ContextGraphQLObjectTypeInterfaces, debugStr?: string): Array<GraphQLInterfaceTypeConfig<any, any, any>>;
    applyHooks(build: Build, hookName: "GraphQLObjectType:fields", input: GraphQLFieldConfigMap<any, any, any>, context: ContextGraphQLObjectTypeFields, debugStr?: string): GraphQLFieldConfigMap<any, any, any>;
    applyHooks(build: Build, hookName: "GraphQLObjectType:fields:field", input: GraphQLFieldConfig<any, any, any>, context: ContextGraphQLObjectTypeFieldsField, debugStr?: string): GraphQLFieldConfig<any, any, any>;
    applyHooks(build: Build, hookName: "GraphQLObjectType:fields:field:args", input: GraphQLFieldConfigArgumentMap, context: ContextGraphQLObjectTypeFieldsFieldArgs, debugStr?: string): GraphQLFieldConfigArgumentMap;
    applyHooks(build: Build, hookName: "GraphQLInterfaceType", input: GraphQLInterfaceTypeConfig<any, any, any>, context: ContextGraphQLInterfaceType, debugStr?: string): GraphQLInterfaceTypeConfig<any, any, any>;
    applyHooks(build: Build, hookName: "GraphQLUnionType", input: GraphileUnionTypeConfig<any, any>, context: ContextGraphQLUnionType, debugStr?: string): GraphileUnionTypeConfig<any, any>;
    applyHooks(build: Build, hookName: "GraphQLUnionType:types", input: Array<GraphQLObjectType<any, any>>, context: ContextGraphQLUnionTypeTypes, debugStr?: string): Array<GraphQLObjectType<any, any>>;
    applyHooks(build: Build, hookName: "GraphQLEnumType", input: GraphQLEnumTypeConfig, context: ContextGraphQLEnumType, debugStr?: string): GraphQLEnumTypeConfig;
    applyHooks(build: Build, hookName: "GraphQLEnumType:values", input: GraphQLEnumValueConfigMap, context: ContextGraphQLEnumTypeValues, debugStr?: string): GraphQLEnumValueConfigMap;
    applyHooks(build: Build, hookName: "GraphQLEnumType:values:value", input: GraphQLEnumValueConfig, context: ContextGraphQLEnumTypeValuesValue, debugStr?: string): GraphQLEnumValueConfig;
    applyHooks(build: Build, hookName: "GraphQLInputObjectType", input: GraphileInputObjectTypeConfig, context: ContextGraphQLInputObjectType, debugStr?: string): GraphQLInputObjectTypeConfig;
    applyHooks(build: Build, hookName: "GraphQLInputObjectType:fields", input: GraphQLInputFieldConfigMap, context: ContextGraphQLInputObjectTypeFields, debugStr?: string): GraphQLInputFieldConfigMap;
    applyHooks(build: Build, hookName: "GraphQLInputObjectType:fields:field", input: GraphQLInputFieldConfig, context: ContextGraphQLInputObjectTypeFieldsField, debugStr?: string): GraphQLInputFieldConfig;
    applyHooks(build: Build, hookName: "finalize", input: GraphQLSchema, context: ContextFinalize, debugStr?: string): GraphQLSchema;
    registerWatcher(listen: WatchUnwatch, unlisten: WatchUnwatch): void;
    createBuild(): Build;
    buildSchema(): GraphQLSchema;
    watchSchema(listener?: SchemaListener): Promise<void>;
    unwatchSchema(): Promise<void>;
}
export default SchemaBuilder;
//# sourceMappingURL=SchemaBuilder.d.ts.map