"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util = require("util");
const SchemaBuilder_1 = require("./SchemaBuilder");
exports.SchemaBuilder = SchemaBuilder_1.default;
const plugins_1 = require("./plugins");
exports.SwallowErrorsPlugin = plugins_1.SwallowErrorsPlugin;
exports.StandardTypesPlugin = plugins_1.StandardTypesPlugin;
exports.NodePlugin = plugins_1.NodePlugin;
exports.QueryPlugin = plugins_1.QueryPlugin;
exports.MutationPlugin = plugins_1.MutationPlugin;
exports.SubscriptionPlugin = plugins_1.SubscriptionPlugin;
exports.ClientMutationIdDescriptionPlugin = plugins_1.ClientMutationIdDescriptionPlugin;
exports.MutationPayloadQueryPlugin = plugins_1.MutationPayloadQueryPlugin;
exports.AddQueriesToSubscriptionsPlugin = plugins_1.AddQueriesToSubscriptionsPlugin;
const resolveNode_1 = require("./resolveNode");
exports.resolveNode = resolveNode_1.default;
var utils_1 = require("./utils");
exports.constantCaseAll = utils_1.constantCaseAll;
exports.formatInsideUnderscores = utils_1.formatInsideUnderscores;
exports.upperFirst = utils_1.upperFirst;
exports.camelCase = utils_1.camelCase;
exports.constantCase = utils_1.constantCase;
exports.upperCamelCase = utils_1.upperCamelCase;
exports.pluralize = utils_1.pluralize;
exports.singularize = utils_1.singularize;
var Live_1 = require("./Live");
exports.LiveSource = Live_1.LiveSource;
exports.LiveProvider = Live_1.LiveProvider;
exports.LiveMonitor = Live_1.LiveMonitor;
exports.LiveCoordinator = Live_1.LiveCoordinator;
exports.getBuilder = async (plugins, options = {}) => {
    const builder = new SchemaBuilder_1.default(options);
    for (let i = 0, l = plugins.length; i < l; i++) {
        const plugin = plugins[i];
        if (typeof plugin !== "function") {
            throw new Error(`Expected a list of plugin functions, instead list contained a non-function at index ${i}: ${util.inspect(plugin)}`);
        }
        // $FlowFixMe: displayName
        builder._setPluginName(plugin.displayName || plugin.name);
        await plugin(builder, options);
        builder._setPluginName(null);
    }
    return builder;
};
exports.buildSchema = async (plugins, options = {}) => {
    const builder = await exports.getBuilder(plugins, options);
    return builder.buildSchema();
};
exports.defaultPlugins = [
    plugins_1.SwallowErrorsPlugin,
    plugins_1.StandardTypesPlugin,
    plugins_1.NodePlugin,
    plugins_1.QueryPlugin,
    plugins_1.MutationPlugin,
    plugins_1.SubscriptionPlugin,
    plugins_1.ClientMutationIdDescriptionPlugin,
    plugins_1.MutationPayloadQueryPlugin,
    plugins_1.AddQueriesToSubscriptionsPlugin,
];
//# sourceMappingURL=index.js.map