import * as graphql from "graphql";
import { ResolveTree } from "graphql-parse-resolve-info";
import pluralize = require("pluralize");
import SchemaBuilder, { BuildBase, ResolvedLookAhead, ContextGraphQLInputObjectTypeFieldsField, ContextGraphQLObjectTypeFieldsField, ScopeGraphQLObjectTypeFieldsField, ScopeGraphQLInputObjectTypeFieldsField } from "./SchemaBuilder";
declare const makeInitialInflection: () => {
    pluralize: typeof pluralize;
    singularize: typeof pluralize.singular;
    upperCamelCase: (str: string) => string;
    camelCase: (str: string) => string;
    constantCase: (str: string) => string;
    /**
     * Built-in names (allows you to override these in the output schema)
     *
     * e.g.:
     *
     * graphile-build:
     *
     * - Query
     * - Mutation
     * - Subscription
     * - Node
     * - PageInfo
     *
     * graphile-build-pg:
     *
     * - Interval
     * - BigInt
     * - BigFloat
     * - BitString
     * - Point
     * - Date
     * - Datetime
     * - Time
     * - JSON
     * - UUID
     * - InternetAddress
     *
     * Other plugins may add their own builtins too; try and avoid conflicts!
     */
    builtin: (name: string) => string;
    /**
     *  When converting a query field to a subscription (live query) field, this allows you to rename it
     */
    live: (name: string) => string;
    /**
     * Try and make something a valid GraphQL 'Name'.
     *
     * Name is defined in GraphQL to match this regexp:
     *
     * /^[_A-Za-z][_0-9A-Za-z]*$/
     *
     * See: https://graphql.github.io/graphql-spec/June2018/#sec-Appendix-Grammar-Summary.Lexical-Tokens
     */
    coerceToGraphQLName: (name: string) => string;
};
export declare type InflectionBase = ReturnType<typeof makeInitialInflection>;
declare type FieldSpec = graphql.GraphQLFieldConfig<any, any>;
export declare type GetDataFromParsedResolveInfoFragmentFunction = (parsedResolveInfoFragment: ResolveTree, Type: graphql.GraphQLOutputType) => ResolvedLookAhead;
export declare type FieldWithHooksFunction = (fieldName: string, spec: FieldSpec | ((context: ContextGraphQLObjectTypeFieldsField) => FieldSpec), fieldScope: ScopeGraphQLObjectTypeFieldsField) => graphql.GraphQLFieldConfig<any, any>;
export declare type InputFieldWithHooksFunction = (fieldName: string, spec: graphql.GraphQLInputFieldConfig | ((context: ContextGraphQLInputObjectTypeFieldsField) => graphql.GraphQLInputFieldConfig), fieldScope: ScopeGraphQLInputObjectTypeFieldsField) => graphql.GraphQLInputFieldConfig;
export default function makeNewBuild(builder: SchemaBuilder): BuildBase;
export {};
//# sourceMappingURL=makeNewBuild.d.ts.map