"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const upperFirstAll = require("lodash/upperFirst");
const camelCaseAll = require("lodash/camelCase");
const plz = require("pluralize");
const bindAll = (obj, keys) => {
    keys.forEach(key => {
        obj[key] = obj[key].bind(obj);
    });
    return obj;
};
exports.bindAll = bindAll;
exports.constantCaseAll = (str) => str
    .replace(/[^a-zA-Z0-9_]+/g, "_")
    .replace(/[A-Z]+/g, "_$&")
    .replace(/__+/g, "_")
    .replace(/^[^a-zA-Z0-9]+/, "")
    .replace(/^[0-9]/, "_$&") // GraphQL enums must not start with a number
    .toUpperCase();
exports.formatInsideUnderscores = (fn) => (str) => {
    const matches = str.match(/^(_*)([\s\S]*?)(_*)$/);
    if (!matches) {
        throw new Error("Impossible?"); // Satiate Flow
    }
    const [, start, middle, end] = matches;
    return `${start}${fn(middle)}${end}`;
};
exports.upperFirst = exports.formatInsideUnderscores(upperFirstAll);
exports.camelCase = exports.formatInsideUnderscores(camelCaseAll);
exports.constantCase = exports.formatInsideUnderscores(exports.constantCaseAll);
exports.upperCamelCase = (str) => exports.upperFirst(exports.camelCase(str));
exports.pluralize = (str) => plz(str);
exports.singularize = (str) => plz.singular(str);
//# sourceMappingURL=utils.js.map